/*
 * Copyright (c) 1993 Addison-Wesley Publishing Company.
 * All rights reserved.  This source code is provided
 * for its instructional value, and is not guaranteed
 * for any particular purpose.
 */
#include <stdio.h>
#include <string.h>
#include <stdarg.h>
#include <stdlib.h>
#include <errno.h>

static void _cmnerr(const char *, va_list);

void
error(const char *fmt, ...)
{
	va_list ap;

	va_start(ap, fmt);
	_cmnerr(fmt, ap);
	va_end(ap);
}

static void
_cmnerr(const char *fmt, va_list ap)
{
	int err;

	/*
	 * Save the value of errno just in case one of the
	 * functions we call changes it.
	 */
	err = errno;

	/*
	 * Print the caller's message, the system error
	 * message if an error has occurred, and a newline.
	 */
	vfprintf(stderr, fmt, ap);
	if (err != 0)
		fprintf(stderr, ": %s", strerror(err));
	putc('\n', stderr);
}

void
fatal(const char *fmt, ...)
{
	va_list ap;

	va_start(ap, fmt);
	_cmnerr(fmt, ap);
	va_end(ap);
	exit(1);
}
